@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import Any, Dict, List
 
-from .literals import EndpointStatusType
+from .literals import EndpointAccessTypeType, EndpointStatusType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -35,14 +35,29 @@ __all__ = (
     "ResponseMetadataTypeDef",
 )
 
-CreateEndpointRequestRequestTypeDef = TypedDict(
-    "CreateEndpointRequestRequestTypeDef",
+_RequiredCreateEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateEndpointRequestRequestTypeDef",
     {
         "OutpostId": str,
         "SubnetId": str,
         "SecurityGroupId": str,
     },
 )
+_OptionalCreateEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateEndpointRequestRequestTypeDef",
+    {
+        "AccessType": EndpointAccessTypeType,
+        "CustomerOwnedIpv4Pool": str,
+    },
+    total=False,
+)
+
+
+class CreateEndpointRequestRequestTypeDef(
+    _RequiredCreateEndpointRequestRequestTypeDef, _OptionalCreateEndpointRequestRequestTypeDef
+):
+    pass
+
 
 CreateEndpointResultTypeDef = TypedDict(
     "CreateEndpointResultTypeDef",
@@ -69,6 +84,11 @@ EndpointTypeDef = TypedDict(
         "Status": EndpointStatusType,
         "CreationTime": datetime,
         "NetworkInterfaces": List["NetworkInterfaceTypeDef"],
+        "VpcId": str,
+        "SubnetId": str,
+        "SecurityGroupId": str,
+        "AccessType": EndpointAccessTypeType,
+        "CustomerOwnedIpv4Pool": str,
     },
     total=False,
 )
